@@ -1,6 +1,6 @@
 set -e
 . repo_venv/bin/activate
-cd $1
+cd "$1"
 python3 -c """
 from predict import *
 model = load_model()
